package com.jiuqi.office.excel;

package .var.folders.cl.9twcgjfx4vsg5zl73c6wxmvm0000gn.T;

import com.jiuqi.grid.GridData;
import com.jiuqi.office.excel.ExcelException;
import com.jiuqi.office.excel.GridIterator;
import com.jiuqi.office.excel.SimpleExportor;
import com.jiuqi.office.excel.WorksheetWriter;
import com.jiuqi.util.StringUtils;
import com.jiuqi.util.zip.ZipEntry;
import com.jiuqi.util.zip.ZipOutputStream;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;

public class BatchExportor {
  private boolean autoAdjust;
  
  private boolean addTitle;
  
  private boolean toSingleFile;
  
  private GridIterator iterator;
  
  private Set filenames;
  
  private HashMap cellStyleHashMap;
  
  private int transparentColor;
  
  private boolean doNotCheckNumberIsNull;
  
  private Map HSSFFontMap;
  
  public BatchExportor(GridIterator iterator) {
    this.iterator = iterator;
    this.filenames = new HashSet();
    this.cellStyleHashMap = new HashMap<Object, Object>();
    this.transparentColor = -16777201;
    this.HSSFFontMap = new HashMap<Object, Object>();
  }
  
  public void setAutoAdjust(boolean autoAdjust) {
    this.autoAdjust = autoAdjust;
  }
  
  public void setAddTitle(boolean addTitle) {
    this.addTitle = addTitle;
  }
  
  public void setToSingleFile(boolean toSingleFile) {
    this.toSingleFile = toSingleFile;
  }
  
  public void setTransparentColor(int transparentColor) {
    this.transparentColor = transparentColor;
  }
  
  public boolean isDoNotCheckNumberIsNull() {
    return this.doNotCheckNumberIsNull;
  }
  
  public void setDoNotCheckNumberIsNull(boolean doNotCheckNumberIsNull) {
    this.doNotCheckNumberIsNull = doNotCheckNumberIsNull;
  }
  
  public boolean isAutoAdjust() {
    return this.autoAdjust;
  }
  
  public boolean isAddTitle() {
    return this.addTitle;
  }
  
  public boolean isToSingleFile() {
    return this.toSingleFile;
  }
  
  public void Export(OutputStream outStream) throws Exception {
    if (this.toSingleFile) {
      exportToSingle(outStream);
    } else {
      exportToBatch(outStream);
    } 
  }
  
  private void exportToSingle(OutputStream outStream) throws ExcelException {
    this.filenames.clear();
    GridData reportData = null;
    HSSFWorkbook wb = new HSSFWorkbook();
    while (this.iterator.next()) {
      reportData = this.iterator.getGridData();
      String rptTitle = validateFileName(this.iterator.getTitle());
      HSSFSheet sheet = wb.createSheet(rptTitle);
      WorksheetWriter sheetWriter = new WorksheetWriter(wb, sheet, reportData, this.cellStyleHashMap);
      sheetWriter.setHSSFFontMap(this.HSSFFontMap);
      sheetWriter.setAddTitle(this.addTitle);
      if (this.addTitle) {
        sheetWriter.setTitle(this.iterator.getTitle());
      } else {
        sheetWriter.setTitle("");
      } 
      sheetWriter.setAutoAdjust(this.autoAdjust);
      sheetWriter.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
      sheetWriter.setTransparentColor(this.transparentColor);
      sheetWriter.writeWorkSheet();
    } 
    try {
      wb.write(outStream);
    } catch (IOException e) {
      throw new ExcelException(e);
    } 
  }
  
  private void exportToBatch(OutputStream outStream) throws ExcelException {
    this.filenames.clear();
    ZipOutputStream zipOutStream = new ZipOutputStream(outStream);
    ZipEntry zipEntry = null;
    byte[] buf = new byte[1024];
    int readLen = 0;
    while (this.iterator.next()) {
      SimpleExportor excelExportor = new SimpleExportor(this.iterator.getTitle(), this.iterator.getGridData());
      excelExportor.setHSSFFontMap((HashMap)this.HSSFFontMap);
      excelExportor.setAddTitle(this.addTitle);
      excelExportor.setAutoAdjust(this.autoAdjust);
      excelExportor.setDoNotCheckNumberIsNull(this.doNotCheckNumberIsNull);
      ByteArrayOutputStream outBuffer = new ByteArrayOutputStream();
      excelExportor.export(outBuffer);
      zipEntry = new ZipEntry(String.valueOf(validateFileName(this.iterator.getTitle())) + ".xls");
      zipEntry.setSize(outBuffer.size());
      Date now = new Date();
      zipEntry.setTime(now.getTime());
      try {
        zipOutStream.putNextEntry(zipEntry);
        InputStream is = new ByteArrayInputStream(outBuffer.toByteArray());
        while ((readLen = is.read(buf, 0, 1024)) != -1)
          zipOutStream.write(buf, 0, readLen); 
      } catch (IOException e) {
        throw new ExcelException(e);
      } 
    } 
    try {
      zipOutStream.close();
    } catch (IOException e) {
      throw new ExcelException(e);
    } 
  }
  
  private String validateFileName(String filename) {
    if (StringUtils.isEmpty(filename) || filename.length() >= 32)
      filename = "report"; 
    String newName = filename;
    int index = 0;
    while (this.filenames.contains(newName)) {
      index++;
      newName = String.valueOf(filename) + "_" + Integer.toString(index);
    } 
    this.filenames.add(newName);
    return newName;
  }
}
